pub struct Node { /* private fields */ }Expand description
A coordinate inside of a Grid.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn cover_row(self_ptr: *mut Node)
pub fn cover_row(self_ptr: *mut Node)
Cover every Node that is horizontally adjacent to this Node.
This Node is not covered.
Sourcepub fn uncover_row(self_ptr: *mut Self)
pub fn uncover_row(self_ptr: *mut Self)
Uncover every Node that is horizontally adjacent to this Node.
This Node is not uncovered.
Sourcepub fn column_index(self_ptr: *const Self) -> usize
pub fn column_index(self_ptr: *const Self) -> usize
Return the column index of this Node.
Sourcepub fn column_ptr(self_ptr: *const Self) -> *mut Column
pub fn column_ptr(self_ptr: *const Self) -> *mut Column
Return a mut pointer to the Column of this Node.