pub struct Possibility {
pub row: usize,
pub column: usize,
pub value: usize,
}Expand description
A position and value for a box inside of a Latin square puzzle.
Fields
row: usizeThe row position of the box.
The values ranges from 0 to side_length - 1.
column: usizeThe column position of the box.
The values ranges from 0 to side_length - 1.
value: usizeThe value present inside of the box.
The values ranges from 1 to side_length.
Implementations
Sourceimpl Possibility
impl Possibility
Sourcepub fn all(side_length: usize) -> impl Iterator<Item = Self>
pub fn all(side_length: usize) -> impl Iterator<Item = Self>
Return an iterator over all possible Possibilitys for the given
side_length.
Sourcepub fn satisfied_constraints(self) -> impl Iterator<Item = Constraint>
pub fn satisfied_constraints(self) -> impl Iterator<Item = Constraint>
Return an iterator over all Constraints that are satisfied by this
Possibility.
Sourcepub fn satisfies(&self, constraint: &Constraint) -> bool
pub fn satisfies(&self, constraint: &Constraint) -> bool
Return true if this Possibility satisfies the given Constraint.