Possibility

Struct Possibility 

pub struct Possibility {
    pub row: usize,
    pub column: usize,
    pub square: usize,
    pub value: usize,
}
A position and value for a box inside of a Sudoku puzzle.

Fields

row: usize

The row position of the box.

The values ranges from 0 to n - 1, where n is the length of the Sudoku board.

column: usize

The column position of the box.

The values ranges from 0 to n - 1, where n is the length of the Sudoku board.

square: usize

The index of the subgrid.

The values ranges from 0 to n - 1, where n is the length of the Sudoku board. This field is redundant in identifying where the box is inside of the Sudoku board, however it is necessary to speed up checking which Constraints are satisfied by this Possibility.

value: usize

The value present inside of the box.

The values ranges from 1 to n, where n is the length of the Sudoku board.

Implementations

Source

impl Possibility

pub fn from_latin(latin: Possibility, box_side_length: usize) -> Self

Convert a latin_square::Possibility to a sudoku::Possibility.

pub fn satisfied_constraints(self) -> impl Iterator<Item = Constraint>

Return an iterator over the Constraints that are satisfied by this Possibility.