pub struct NQueens {
pub possibilities: Vec<Possibility>,
pub constraints: Vec<Constraint>,
pub side_length: usize,
}Expand description
An instance of the n queens problem.
Fields
possibilities: Vec<Possibility>The list of possible positions that could solve the n queens puzzle.
constraints: Vec<Constraint>The list of constraints that must be satisfied for this n queens
puzzle.
side_length: usizeThe length of the chess board side, equal to n.
Implementations
Sourceimpl NQueens
impl NQueens
Sourcepub fn new(
side_length: usize,
filled_values: impl IntoIterator<Item = Possibility>,
) -> Self
pub fn new( side_length: usize, filled_values: impl IntoIterator<Item = Possibility>, ) -> Self
Create a new instance of the n queens problem with the given filled
values and side length.